@@ -22,7 +22,7 @@
  ********************************************************************/
 #ifndef COMMONDEFS_H
 #define COMMONDEFS_H
-
+#include <QObject>
 
 enum BallColor { Blue=0, Brown, Cyan, Green, Red, Violet, Yellow, NumColors };
 
@@ -32,10 +32,10 @@ struct FieldPos
     int y;
     FieldPos( int _x=-1, int _y=-1) : x(_x), y(_y) { }
     bool isValid() const { return (x != -1 && y != -1); }
-    bool operator==(const FieldPos& other) const
+    bool operator==(FieldPos other) const
     {
         return (x == other.x && y == other.y);
     }
 };
-
+Q_DECLARE_TYPEINFO(FieldPos, Q_MOVABLE_TYPE);
 #endif
